Push Menu Plugin | AdminLTE 3 Documentation
Description: AdminLTE v3 Documentaion

Push Menu Plugin | AdminLTE v3 Documentaion

# Push Menu Plugin

The PushMenu plugin controls the toggle button of the main sidebar.

##### Usage

This plugin can be activated as a jQuery plugin or using the data api.

###### Data API

Add `data-widget="pushmenu"` to a button to activate the plugin.

    <button class="btn btn-primary" data-widget="pushmenu">Toggle Sidebar</button>

###### jQuery

    $('.sidebar-toggle-btn').PushMenu(options)

##### Options

Name | Type | Default | Description
--- | --- | --- | ---
autoCollapseSize | Boolean/Number | FALSE | Screen width in pixels to trigger auto collapse sidebar
enableRemember | Boolean | FALSE | Remember sidebar state and set after page refresh.
noTransitionAfterReload | Boolean | TRUE | Hold Transition after page refresh.

> ##### Tip!

> You can use any option via the data-attributes like this to enable auto collapse sidebar on 768 pixels width.

>     <button class="btn btn-primary" data-widget="pushmenu" data-auto-collapse-size="768">Toggle Sidebar</button>

##### Events

Event Type | Description
--- | ---
collapsed.lte.pushmenu | Fired when the sidebar collapsed.
shown.lte.pushmenu | Fired when the sidebar shown.

Example: `$(document).on('shown.lte.pushmenu', handleExpandedEvent)`

##### Methods

Method | Description
--- | ---
toggle | Toggles the state of the menu between expanded and collapsed.
collapse | Collapses the sidebar menu.
expand | Expands the sidebar menu

Example: `$('[data-widget="pushmenu"]').PushMenu('toggle')`